pub trait CookieStore: Send + Sync {
// Required methods
fn set_cookies(
&self,
cookie_headers: &mut dyn Iterator<Item = &HeaderValue>,
url: &Url,
);
fn cookies(&self, url: &Url) -> Option<HeaderValue>;
}Expand description
Actions for a persistent cookie store providing session support.
Required Methods
Store a set of Set-Cookie header values received from url
Get any Cookie values in the store for url
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".