IntoResolve

Trait IntoResolve 

pub trait IntoResolve { }
Available on docsrs and not (WebAssembly and (target_os=unknown or bare-metal)) only.
A more general trait implemented for types implementing Resolve.

Unnameable, only exported to aid seeing what implements this.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoResolve for Arc<dyn Resolve>

Source

impl<R> IntoResolve for Arc<R>
where R: Resolve + 'static,

Implementors

Source

impl<R> IntoResolve for R
where R: Resolve + 'static,