IntoUrl

Trait IntoUrl 

pub trait IntoUrl: IntoUrlSealed { }
A trait to try to convert some type into a Url.

This trait is “sealed”, such that only types within reqwest can implement it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoUrl for String

Source

impl<'a> IntoUrl for &'a String

Source

impl<'a> IntoUrl for &'a str

Implementors