pub trait UnixSocketProvider { }Available on
docsrs and Unix and not (WebAssembly and (target_os=unknown or bare-metal)) only.Expand description
A provider for Unix Domain Socket paths.
This trait is sealed. This allows us expand the support in the future by controlling who can implement the trait.
It’s available in the docs to see what type may be passed in.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".