IntoResolve

Trait IntoResolve 

pub trait IntoResolve { }
Available on non-WebAssembly and docsrs only.
A more general trait implemented for types implementing Resolve.

Unnameable, only exported to aid seeing what implements this.

Implementations on Foreign Types

Source

impl IntoResolve for Arc<dyn Resolve>

Source

impl<R> IntoResolve for Arc<R>
where R: Resolve + 'static,

Implementors

Source

impl<R> IntoResolve for R
where R: Resolve + 'static,