pub trait IntoUrl: IntoUrlSealed { }Expand description
A trait to try to convert some type into a Url.
This trait is “sealed”, such that only types within reqwest can implement it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".