IntoUrl

Trait IntoUrl 

pub trait IntoUrl: IntoUrlSealed { }
A trait to try to convert some type into a Url.

This trait is “sealed”, such that only types within reqwest can implement it.

Implementations on Foreign Types

Source

impl IntoUrl for &str

Source

impl IntoUrl for &String

Source

impl IntoUrl for String

Implementors