Trait IntoUrl
trait IntoUrl: IntoUrlSealed
A trait to try to convert some type into a Url.
This trait is "sealed", such that only types within reqwest can implement it.
IntoUrltrait IntoUrl: IntoUrlSealed
A trait to try to convert some type into a Url.
This trait is "sealed", such that only types within reqwest can implement it.