Trait ResponseBuilderExt

trait ResponseBuilderExt

Extension trait for http::response::Builder objects

Allows the user to add a Url to the http::Response

Required Methods

fn url(self: Self, url: Url) -> Self

A builder method for the http::response::Builder type that allows the user to add a Url to the http::Response

Implementors