UnixSocketProvider

Trait UnixSocketProvider 

pub trait UnixSocketProvider { }
Available on Unix and not (WebAssembly and (target_os=unknown or bare-metal)) and docsrs only.
A provider for Unix Domain Socket paths.

This trait is sealed. This allows us expand the support in the future by controlling who can implement the trait.

It’s available in the docs to see what type may be passed in.

Implementations on Foreign Types

Source

impl UnixSocketProvider for &str

Source

impl UnixSocketProvider for &Path

Source

impl UnixSocketProvider for String

Source

impl UnixSocketProvider for Arc<Path>

Source

impl UnixSocketProvider for PathBuf

Implementors