pub trait UnixSocketProvider { }Available on Unix and not (WebAssembly and (
target_os=unknown or bare-metal)) and docsrs only.Expand description
A provider for Unix Domain Socket paths.
This trait is sealed. This allows us expand the support in the future by controlling who can implement the trait.
It’s available in the docs to see what type may be passed in.